declare type Ref = {
    $ref: string;
};
declare type SpecSchema = {
    readonly properties?: Record<string, unknown>;
    readonly additionalProperties?: boolean | Record<string, unknown>;
    readonly patternProperties?: Record<string, unknown>;
    readonly items?: Record<string, unknown>;
};
declare type SpecSchemas = Record<string, SpecSchema>;
declare type OpenApiSpec = {
    readonly components: {
        readonly schemas: SpecSchemas;
    };
    readonly paths?: Record<string, unknown>;
};
declare type SwaggerSpec = {
    readonly definitions: SpecSchemas;
    readonly paths?: Record<string, unknown>;
};
export declare type Spec = OpenApiSpec | SwaggerSpec;
declare type ExtractSchemaPropertiesKey = `properties` | `additionalProperties` | `patternProperties` | `items`;
declare type Timings = {
    readonly begin: number;
    readonly end: number;
    readonly delta: number;
};
declare type TransformWithTimingsResult = {
    readonly spec: Spec;
    readonly timings: {
        readonly rewriteSchemasAbsoluteRefs: Timings;
        readonly extractSchemasProperties: Timings;
        readonly mergeRefs: Timings;
        readonly deleteUnusedSchemas: Timings;
        readonly total: Timings;
    };
};
export declare type TransformOptions = {
    readonly rewriteSchemasAbsoluteRefs?: boolean;
    readonly extractSchemasProperties?: boolean | ExtractSchemaPropertiesKey[];
    readonly mergeRefs?: Ref[];
    readonly deleteUnusedSchemas?: boolean;
};
export declare class SpecTransformer {
    private readonly DEBUG;
    private readonly spec;
    private readonly schemasPath;
    constructor(spec: unknown, DEBUG?: boolean);
    private readonly _DEBUG;
    private readonly throw;
    private readonly getSchemaPath;
    private readonly getSchema;
    private readonly getSchemaKeys;
    private readonly getAtPath;
    private readonly getAtPathSafe;
    private readonly resolveRef;
    private readonly setAtPath;
    private readonly deleteAtPath;
    private readonly findFirstDeep;
    private readonly hasProperRef;
    private readonly deleteUnusedSchemas;
    private readonly rewriteSchemaAbsoluteRefs;
    private readonly rewriteSchemasAbsoluteRefs;
    private readonly extractSchemaPathAsSchema;
    private readonly extractSchemaPropertiesAtKey;
    private readonly extractSchemaProperties;
    private readonly extractSchemasProperties;
    private readonly mergeRef;
    private readonly mergeRefs;
    readonly transformWithTimings: (opts?: TransformOptions) => TransformWithTimingsResult;
    readonly transform: (opts?: TransformOptions) => Spec;
}
export {};
